@@ -1,7 +1,7 @@
 package App::PerlbrewUtils;
 
-our $DATE = '2016-03-17'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $DATE = '2016-06-02'; # DATE
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,6 +58,11 @@ _
         schema => ['str*'],
         tags => ['category:filtering'],
     },
+    exclude_dev => {
+        summary => 'Exclude dev perl(s)',
+        schema => ['bool'],
+        tags => ['category:filtering'],
+    },
 );
 
 sub _version_eq {
@@ -97,6 +102,13 @@ sub _version_lt {
     $res;
 }
 
+sub _version_dev {
+    my ($v) = @_;
+
+    $v =~ /^v?\d+\.(\d+)/ or return 0;
+    $1 % 2 ? 1:0;
+}
+
 sub _filter_perl {
     my ($perl, $args) = @_;
 
@@ -160,9 +172,29 @@ sub _filter_perl {
         return 0 if !_version_lt($perl->{version}, $args->{xmax_version});
     }
 
+  FILTER_EXCLUDE_DEV:
+    {
+        last unless $args->{exclude_dev};
+        return 0 if _version_dev($perl->{version});
+    }
+
     1;
 }
 
+sub _find_perl_by_name {
+    require App::perlbrew;
+
+    my ($name) = @_;
+
+    my $pb = App::perlbrew->new;
+
+    for my $perl ($pb->installed_perls) {
+        next unless $perl->{name} eq $name;
+        return $perl;
+    }
+    return undef;
+}
+
 1;
 # ABSTRACT: More utilities for perlbrew
 
@@ -178,7 +210,7 @@ App::PerlbrewUtils - More utilities for perlbrew
 
 =head1 VERSION
 
-This document describes version 0.03 of App::PerlbrewUtils (from Perl distribution App-PerlbrewUtils), released on 2016-03-17.
+This document describes version 0.04 of App::PerlbrewUtils (from Perl distribution App-PerlbrewUtils), released on 2016-06-02.
 
 =head1 DESCRIPTION
 
@@ -186,6 +218,8 @@ This distribution contains the following utilities:
 
 =over
 
+=item * L<perlbrew-clean-site-lib>
+
 =item * L<perlbrew-list-more>
 
 =item * L<perlbrew-module-version>
